@@ -1,2 +1,2 @@
 from pyduinocli.commands.arduino import ArduinoCliCommand as Arduino
-from pyduinocli.errors import ArduinoError
+from pyduinocli.errors.arduinoerror import ArduinoError
