@@ -26,3 +26,12 @@ CLEAN = 'clean'
 DEBUG = 'debug'
 BURN_BOOTLOADER = 'burn-bootloader'
 COMPLETION = 'completion'
+EXAMPLES = 'examples'
+OUTDATED = 'outdated'
+ARCHIVE = 'archive'
+UPDATE = 'update'
+ADD = 'add'
+DELETE = 'delete'
+REMOVE = 'remove'
+SET = 'set'
+MONITOR = 'monitor'
\ No newline at end of file
